<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>Dialog</name>
    <message>
        <source>Leave</source>
        <translation>Forlad</translation>
    </message>
    <message>
        <source>What do you want the computer to do?</source>
        <translation>Hvad vil du have computeren til at gøre?</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Slumre</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Fortryd</translation>
    </message>
</context>
</TS>